<p align="center">
<img width="150px" src="https://user-images.githubusercontent.com/18649508/141604792-b256023d-c751-46d8-bab5-29a207d714ba.png"/>
</p>

<hr/>

<p align="center">
<a href="https://persiaml-tutorials.pages.dev" rel="nofollow"><img src="https://camo.githubusercontent.com/5f2d7c7e08b25fa4f95ce11be89982f25bb81bdef3e15f90b765aa91db371ff6/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f7475746f7269616c732d70617373696e672d677265656e" alt="tutorials" data-canonical-src="https://img.shields.io/badge/tutorials-passing-green" style="max-width: 100%;"></a>
<a href="https://persiaml.pages.dev" rel="nofollow"><img src="https://camo.githubusercontent.com/bf535e4ed96252a7731419446fe108bb36ce4b91e4960630ceccf31558329193/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f646f63756d656e746174696f6e2d70617373696e672d677265656e" alt="Documentation Status" data-canonical-src="https://img.shields.io/badge/documentation-passing-green" style="max-width: 100%;"></a>
<a href="https://badge.fury.io/py/persia" rel="nofollow"><img src="https://camo.githubusercontent.com/d6f9832aba04a67bbb6643eb81bd6be2173e12e51150553f30f16b629f40dc73/68747470733a2f2f62616467652e667572792e696f2f70792f7065727369612e737667" alt="PyPI version" data-canonical-src="https://badge.fury.io/py/persia.svg" style="max-width: 100%;"></a> <a href="https://hub.docker.com/u/persiaml" rel="nofollow"><img src="https://github.com/PersiaML/containers/actions/workflows/dockerhub.yml/badge.svg" alt="dockerhub" style="max-width: 100%;"></a>
</p>

**PERSIA** (**P**arallel r**E**commendation t**R**aining **S**ystem with hyb**R**id **A**cceleration) is a PyTorch-based system for training deep learning recommendation models on commodity hardware. It supports models containing more than 100 trillion parameters, and is by far the fastest open source deep learning recommendation model training system. PERSIA is developed by [AI platform@Kuaishou Technology](https://www.kuaishou.com/en).

*Disclaimer: The program is already usable and has served many important businesses. However, the official documentation and tutorials are still under heavy construction (there are some materials on [tutorials website](https://persiaml-tutorials.pages.dev), but they are pretty raw). We encourage adventurers to try out PERSIA and contribute!*
